
from setuptools import setup

setup(name="StockTrader",
	version="1.1",
	description="It helps one know the value of their stock",
	url="https://github.com/madhuradlakha/Stock-Trading-API/blob/master/stock.py",
	author="Madhur Adlakha",
	author_email="madhuradlakha@yahoo.co.in",
	license='MIT',
	packages=["StockTrader"],
	scripts=["bin/StockTrader"],
	zip_safe=False)
